Convert

Trait Convert 

pub trait Convert<Input> {
    type Output;
    type Error;

    // Required method
    fn try_convert(&mut self, input: Input) -> Result<Self::Output, Self::Error>;
}
Fallible conversion from one type to another.

Required Associated Types

type Output

Converted type if the conversion succeeds.

type Error

Error type if the conversion fails

Required Methods

fn try_convert(&mut self, input: Input) -> Result<Self::Output, Self::Error>

Try to convert an instance of the input type to the output type. The conversion may fail, in which case an error is returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors