CyclesAccounting

Struct CyclesAccounting 

pub struct CyclesAccounting<ChargingPolicy> { /* private fields */ }
A middleware to handle cycles accounting, i.e. verify if sufficiently many cycles are available in a request. The cost of sending the request is calculated by ic_cdk_management_canister::cost_http_request.

Implementations

Source

impl<ChargingPolicy> CyclesAccounting<ChargingPolicy>

pub fn new(charging_policy: ChargingPolicy) -> Self

Create a new middleware given the charging policy.