pub trait MaxResponseBytesRequestExtension: Sized {
// Required methods
fn set_max_response_bytes(&mut self, value: u64);
fn get_max_response_bytes(&self) -> Option<u64>;
// Provided method
fn max_response_bytes(self, value: u64) -> Self { ... }
}Expand description
Add support for max response bytes.
Required Methods
Sourcefn set_max_response_bytes(&mut self, value: u64)
fn set_max_response_bytes(&mut self, value: u64)
Set the max response bytes.
If provided, the value must not exceed 2MB (2_000_000B). The call will be charged based on this parameter. If not provided, the maximum of 2MB will be used.
Sourcefn get_max_response_bytes(&self) -> Option<u64>
fn get_max_response_bytes(&self) -> Option<u64>
Retrieves the current max response bytes value, if any.
Provided Methods
Sourcefn max_response_bytes(self, value: u64) -> Self
fn max_response_bytes(self, value: u64) -> Self
Convenience method to use the builder pattern.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".