pub struct CyclesAccounting<ChargingPolicy> { /* private fields */ }Expand description
A middleware to handle cycles accounting, i.e. verify if sufficiently many cycles are available in a request.
The cost of sending the request is calculated by ic_cdk_management_canister::cost_http_request.
Implementations
Sourceimpl<ChargingPolicy> CyclesAccounting<ChargingPolicy>
impl<ChargingPolicy> CyclesAccounting<ChargingPolicy>